summaryrefslogtreecommitdiffstats
path: root/import/chips/common/utils
diff options
context:
space:
mode:
authorClaus Michael Olsen <cmolsen@us.ibm.com>2017-12-12 11:20:34 -0600
committerJoshua Hunsberger <jahunsbe@us.ibm.com>2018-02-01 16:15:34 -0600
commit2af24d81c684f592f6a6c4debd83c9598abe8300 (patch)
treef02e2d4b471877a971bbf0bbeee7c78cfc2eb697 /import/chips/common/utils
parentd18484592cfb0b7aeb51292e4d23bb484f2aedec (diff)
downloadtalos-hcode-2af24d81c684f592f6a6c4debd83c9598abe8300.tar.gz
talos-hcode-2af24d81c684f592f6a6c4debd83c9598abe8300.zip
Adding CT_P9A to the enum list of chip types.
I inserted P9A before CT_CEN for purely estaetic reasons. Since the current Centaur image in EKB isn't being used yet, this should be safe (as otherwise there would be a co-req situation). Change-Id: Ia5ef9950644eacea3fdc28a0195502bdcae44327 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/50812 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: HWSV CI <hwsv-ci+hostboot@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Joseph J. McGill <jmcgill@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Reviewed-by: Richard J. Knight <rjknight@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com>
Diffstat (limited to 'import/chips/common/utils')
-rw-r--r--import/chips/common/utils/imageProcs/common_ringId.H9
1 files changed, 5 insertions, 4 deletions
diff --git a/import/chips/common/utils/imageProcs/common_ringId.H b/import/chips/common/utils/imageProcs/common_ringId.H
index b8136a3b..9bac4666 100644
--- a/import/chips/common/utils/imageProcs/common_ringId.H
+++ b/import/chips/common/utils/imageProcs/common_ringId.H
@@ -134,13 +134,13 @@ enum TorMagicNum
//
// Chip types and List to represent p9n, p9c, cen (centaur)
// NB! There's a matching CHIP_TYPE_LIST definition in common_ringId.C
//
enum ChipType
{
- CT_P9N, // ==P9 for now
- CT_P9C, // ==P9 for now
+ CT_P9N,
+ CT_P9C,
+ CT_P9A,
CT_CEN,
NUM_CHIP_TYPES
};
@@ -155,6 +155,7 @@ static const ChipTypeList_t CHIP_TYPE_LIST[] =
{
{"p9n", CT_P9N},
{"p9c", CT_P9C},
+ {"p9a", CT_P9A},
{"cen", CT_CEN},
};
OpenPOWER on IntegriCloud
@@ -134,13 +134,13 @@ enum TorMagicNum
//
-// Chip types and List to represent p9n, p9c, cen (centaur)
-// NB! There's a matching CHIP_TYPE_LIST definition in common_ringId.C
+// Chip types and List to represent p9n, p9c, p9a, cen (centaur)
//
enum ChipType